==> pdapi-1.20.1+0.3.9-sources.jar: ml/pluto7073/pdapi/compat/rei/display/IngredientSequenceDisplay.java <==
package ml.pluto7073.pdapi.compat.rei.display;

import com.google.common.collect.Lists;
import me.shedaniel.rei.api.common.category.CategoryIdentifier;
import me.shedaniel.rei.api.common.display.basic.BasicDisplay;
import me.shedaniel.rei.api.common.entry.EntryIngredient;
import me.shedaniel.rei.api.common.util.EntryIngredients;
import ml.pluto7073.pdapi.compat.rei.DrinkREI;
import ml.pluto7073.pdapi.specialty.InProgressItemRegistry;
import ml.pluto7073.pdapi.specialty.SpecialtyDrink;
import net.minecraft.class_156;
import net.minecraft.class_1799;
import net.minecraft.class_2960;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.Optional;

public class IngredientSequenceDisplay extends BasicDisplay {

    public IngredientSequenceDisplay(SpecialtyDrink drink) {
        super(class_156.method_656(() -> {
            class_1799 base = drink.base().buildItemStack();
            if (InProgressItemRegistry.isInProgressItem(base.method_7909())) {
                base = new class_1799(InProgressItemRegistry.getBase(base.method_7909()));
            }
            List<EntryIngredient> list = new ArrayList<>(List.of(EntryIngredients.of(base)));
            list.addAll(DrinkREI.Util.condenseIngredients(drink.stepsToIngredientList()));
            return list;
        }), Collections.singletonList(EntryIngredients.of(drink.getAsItem())), Optional.of(drink.id()));
    }

    public IngredientSequenceDisplay(List<EntryIngredient> inputs, List<EntryIngredient> outputs, Optional<class_2960> id) {
        super(inputs, outputs, id);
    }

    @Override
    public CategoryIdentifier<?> getCategoryIdentifier() {
        return DrinkREI.INGREDIENT_SEQUENCE;
    }

}

==> pdapi-1.20.6+2.0.2-sources.jar: ml/pluto7073/pdapi/compat/rei/display/IngredientSequenceDisplay.java <==
package ml.pluto7073.pdapi.compat.rei.display;

import com.google.common.collect.Lists;
import me.shedaniel.rei.api.common.category.CategoryIdentifier;
import me.shedaniel.rei.api.common.display.basic.BasicDisplay;
import me.shedaniel.rei.api.common.entry.EntryIngredient;
import me.shedaniel.rei.api.common.util.EntryIngredients;
import ml.pluto7073.pdapi.compat.rei.DrinkREI;
import ml.pluto7073.pdapi.specialty.InProgressItemRegistry;
import ml.pluto7073.pdapi.specialty.SpecialtyDrink;
import net.minecraft.class_156;
import net.minecraft.class_1799;
import net.minecraft.class_2960;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.Optional;

public class IngredientSequenceDisplay extends BasicDisplay {

    public IngredientSequenceDisplay(SpecialtyDrink drink) {
        super(class_156.method_656(() -> {
            class_1799 base = new class_1799(drink.base());
            if (InProgressItemRegistry.isInProgressItem(base.method_7909())) {
                base = new class_1799(InProgressItemRegistry.getBase(base.method_7909()));
            }
            List<EntryIngredient> list = new ArrayList<>(List.of(EntryIngredients.of(base)));
            list.addAll(DrinkREI.Util.condenseIngredients(drink.stepsToIngredientList()));
            return list;
        }), Collections.singletonList(EntryIngredients.of(drink.getAsItem())), Optional.of(drink.id()));
    }

    public IngredientSequenceDisplay(List<EntryIngredient> inputs, List<EntryIngredient> outputs, Optional<class_2960> id) {
        super(inputs, outputs, id);
    }

    @Override
    public CategoryIdentifier<?> getCategoryIdentifier() {
        return DrinkREI.INGREDIENT_SEQUENCE;
    }

}
